@@ -5,9 +5,10 @@
 
 package JCM::Boilerplate v0.01.11;
 # ABSTRACT: Default Boilerplate for Joel's Code
-$JCM::Boilerplate::VERSION = '1.011';
+$JCM::Boilerplate::VERSION = '1.012';
 
 use v5.22;
+use strict;
 
 use feature 'signatures';
 no warnings 'experimental::signatures';
@@ -45,16 +46,19 @@ sub import($self, $type='script') {
     English->import::into($target);
     Smart::Comments->import::into($target, '-ENV', '###');
 
-    feature->import::into($target, 'postderef');    # Not needed if >= 5.23.1
-    feature->import::into($target, 'refaliasing');
-    feature->import::into($target, 'signatures');   # Not needed if >= 5.23.?
+    feature->import::into($target, 'postderef');    # Not needed if feature budle >= 5.23.1
+
+    # We haven't been using this
+    # feature->import::into($target, 'refaliasing');
+    feature->import::into($target, 'signatures');
+
     feature->import::into($target, 'switch');
     feature->import::into($target, 'unicode_strings');
-    warnings->unimport::out_of($target, 'experimental::refaliasing');
+    # warnings->unimport::out_of($target, 'experimental::refaliasing');
+    warnings->unimport::out_of($target, 'experimental::signatures');
 
     if ($PERL_VERSION lt v5.24.0) {
         warnings->unimport::out_of($target, 'experimental::postderef');
-        warnings->unimport::out_of($target, 'experimental::signatures');
     }
 
     # For "switch" feature
@@ -75,7 +79,7 @@ JCM::Boilerplate - Default Boilerplate for Joel's Code
 
 =head1 VERSION
 
-version 1.011
+version 1.012
 
 =head1 SYNOPSIS
 
